# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper
from spotifywebapiwithfixesandimprovementsfromsonallux.models.author_object import AuthorObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.copyright_object import CopyrightObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.external_url_object import ExternalUrlObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.image_object import ImageObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.narrator_object import NarratorObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.paging_simplified_chapter_object import PagingSimplifiedChapterObject


class AudiobookObject(object):

    """Implementation of the 'AudiobookObject' model.

    Attributes:
        authors (List[AuthorObject]): The author(s) for the audiobook.
        available_markets (List[str]): A list of the countries in which the
            audiobook can be played, identified by their [ISO 3166-1
            alpha-2](http://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) code.
        copyrights (List[CopyrightObject]): The copyright statements of the
            audiobook.
        description (str): A description of the audiobook. HTML tags are
            stripped away from this field, use `html_description` field in
            case HTML tags are needed.
        html_description (str): A description of the audiobook. This field may
            contain HTML tags.
        edition (str): The edition of the audiobook.
        explicit (bool): Whether or not the audiobook has explicit content
            (true = yes it does; false = no it does not OR unknown).
        external_urls (ExternalUrlObject): External URLs for this audiobook.
        href (str): A link to the Web API endpoint providing full details of
            the audiobook.
        id (str): The [Spotify
            ID](/documentation/web-api/concepts/spotify-uris-ids) for the
            audiobook.
        images (List[ImageObject]): The cover art for the audiobook in various
            sizes, widest first.
        languages (List[str]): A list of the languages used in the audiobook,
            identified by their [ISO
            639](https://en.wikipedia.org/wiki/ISO_639) code.
        media_type (str): The media type of the audiobook.
        name (str): The name of the audiobook.
        narrators (List[NarratorObject]): The narrator(s) for the audiobook.
        publisher (str): The publisher of the audiobook.
        mtype (str): The object type.
        uri (str): The [Spotify
            URI](/documentation/web-api/concepts/spotify-uris-ids) for the
            audiobook.
        total_chapters (int): The number of chapters in this audiobook.
        chapters (PagingSimplifiedChapterObject): The chapters of the
            audiobook.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "authors": 'authors',
        "available_markets": 'available_markets',
        "copyrights": 'copyrights',
        "description": 'description',
        "html_description": 'html_description',
        "explicit": 'explicit',
        "external_urls": 'external_urls',
        "href": 'href',
        "id": 'id',
        "images": 'images',
        "languages": 'languages',
        "media_type": 'media_type',
        "name": 'name',
        "narrators": 'narrators',
        "publisher": 'publisher',
        "mtype": 'type',
        "uri": 'uri',
        "total_chapters": 'total_chapters',
        "chapters": 'chapters',
        "edition": 'edition'
    }

    _optionals = [
        'edition',
    ]

    def __init__(self,
                 authors=None,
                 available_markets=None,
                 copyrights=None,
                 description=None,
                 html_description=None,
                 explicit=None,
                 external_urls=None,
                 href=None,
                 id=None,
                 images=None,
                 languages=None,
                 media_type=None,
                 name=None,
                 narrators=None,
                 publisher=None,
                 uri=None,
                 total_chapters=None,
                 chapters=None,
                 edition=APIHelper.SKIP):
        """Constructor for the AudiobookObject class"""

        # Initialize members of the class
        self.authors = authors 
        self.available_markets = available_markets 
        self.copyrights = copyrights 
        self.description = description 
        self.html_description = html_description 
        if edition is not APIHelper.SKIP:
            self.edition = edition 
        self.explicit = explicit 
        self.external_urls = external_urls 
        self.href = href 
        self.id = id 
        self.images = images 
        self.languages = languages 
        self.media_type = media_type 
        self.name = name 
        self.narrators = narrators 
        self.publisher = publisher 
        self.mtype = 'audiobook' 
        self.uri = uri 
        self.total_chapters = total_chapters 
        self.chapters = chapters 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        authors = None
        if dictionary.get('authors') is not None:
            authors = [AuthorObject.from_dictionary(x) for x in dictionary.get('authors')]
        available_markets = dictionary.get("available_markets") if dictionary.get("available_markets") else None
        copyrights = None
        if dictionary.get('copyrights') is not None:
            copyrights = [CopyrightObject.from_dictionary(x) for x in dictionary.get('copyrights')]
        description = dictionary.get("description") if dictionary.get("description") else None
        html_description = dictionary.get("html_description") if dictionary.get("html_description") else None
        explicit = dictionary.get("explicit") if "explicit" in dictionary.keys() else None
        external_urls = ExternalUrlObject.from_dictionary(dictionary.get('external_urls')) if dictionary.get('external_urls') else None
        href = dictionary.get("href") if dictionary.get("href") else None
        id = dictionary.get("id") if dictionary.get("id") else None
        images = None
        if dictionary.get('images') is not None:
            images = [ImageObject.from_dictionary(x) for x in dictionary.get('images')]
        languages = dictionary.get("languages") if dictionary.get("languages") else None
        media_type = dictionary.get("media_type") if dictionary.get("media_type") else None
        name = dictionary.get("name") if dictionary.get("name") else None
        narrators = None
        if dictionary.get('narrators') is not None:
            narrators = [NarratorObject.from_dictionary(x) for x in dictionary.get('narrators')]
        publisher = dictionary.get("publisher") if dictionary.get("publisher") else None
        uri = dictionary.get("uri") if dictionary.get("uri") else None
        total_chapters = dictionary.get("total_chapters") if dictionary.get("total_chapters") else None
        chapters = PagingSimplifiedChapterObject.from_dictionary(dictionary.get('chapters')) if dictionary.get('chapters') else None
        edition = dictionary.get("edition") if dictionary.get("edition") else APIHelper.SKIP
        # Return an object of this model
        return cls(authors,
                   available_markets,
                   copyrights,
                   description,
                   html_description,
                   explicit,
                   external_urls,
                   href,
                   id,
                   images,
                   languages,
                   media_type,
                   name,
                   narrators,
                   publisher,
                   uri,
                   total_chapters,
                   chapters,
                   edition)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'authors={self.authors!r}, '
                f'available_markets={self.available_markets!r}, '
                f'copyrights={self.copyrights!r}, '
                f'description={self.description!r}, '
                f'html_description={self.html_description!r}, '
                f'edition={(self.edition if hasattr(self, "edition") else None)!r}, '
                f'explicit={self.explicit!r}, '
                f'external_urls={self.external_urls!r}, '
                f'href={self.href!r}, '
                f'id={self.id!r}, '
                f'images={self.images!r}, '
                f'languages={self.languages!r}, '
                f'media_type={self.media_type!r}, '
                f'name={self.name!r}, '
                f'narrators={self.narrators!r}, '
                f'publisher={self.publisher!r}, '
                f'mtype={self.mtype!r}, '
                f'uri={self.uri!r}, '
                f'total_chapters={self.total_chapters!r}, '
                f'chapters={self.chapters!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'authors={self.authors!s}, '
                f'available_markets={self.available_markets!s}, '
                f'copyrights={self.copyrights!s}, '
                f'description={self.description!s}, '
                f'html_description={self.html_description!s}, '
                f'edition={(self.edition if hasattr(self, "edition") else None)!s}, '
                f'explicit={self.explicit!s}, '
                f'external_urls={self.external_urls!s}, '
                f'href={self.href!s}, '
                f'id={self.id!s}, '
                f'images={self.images!s}, '
                f'languages={self.languages!s}, '
                f'media_type={self.media_type!s}, '
                f'name={self.name!s}, '
                f'narrators={self.narrators!s}, '
                f'publisher={self.publisher!s}, '
                f'mtype={self.mtype!s}, '
                f'uri={self.uri!s}, '
                f'total_chapters={self.total_chapters!s}, '
                f'chapters={self.chapters!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.models.recommendation_seed_object import RecommendationSeedObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.track_object import TrackObject


class RecommendationsObject(object):

    """Implementation of the 'RecommendationsObject' model.

    Attributes:
        seeds (List[RecommendationSeedObject]): An array of recommendation
            seed objects.
        tracks (List[TrackObject]): An array of track objects ordered
            according to the parameters supplied.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "seeds": 'seeds',
        "tracks": 'tracks'
    }

    def __init__(self,
                 seeds=None,
                 tracks=None):
        """Constructor for the RecommendationsObject class"""

        # Initialize members of the class
        self.seeds = seeds 
        self.tracks = tracks 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        seeds = None
        if dictionary.get('seeds') is not None:
            seeds = [RecommendationSeedObject.from_dictionary(x) for x in dictionary.get('seeds')]
        tracks = None
        if dictionary.get('tracks') is not None:
            tracks = [TrackObject.from_dictionary(x) for x in dictionary.get('tracks')]
        # Return an object of this model
        return cls(seeds,
                   tracks)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'seeds={self.seeds!r}, '
                f'tracks={self.tracks!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'seeds={self.seeds!s}, '
                f'tracks={self.tracks!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper
from spotifywebapiwithfixesandimprovementsfromsonallux.models.external_url_object import ExternalUrlObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.followers_object import FollowersObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.image_object import ImageObject


class ArtistObject(object):

    """Implementation of the 'ArtistObject' model.

    Attributes:
        external_urls (ExternalUrlObject): Known external URLs for this artist.
        followers (FollowersObject): Information about the followers of the
            artist.
        genres (List[str]): A list of the genres the artist is associated
            with. If not yet classified, the array is empty.
        href (str): A link to the Web API endpoint providing full details of
            the artist.
        id (str): The [Spotify
            ID](/documentation/web-api/concepts/spotify-uris-ids) for the
            artist.
        images (List[ImageObject]): Images of the artist in various sizes,
            widest first.
        name (str): The name of the artist.
        popularity (int): The popularity of the artist. The value will be
            between 0 and 100, with 100 being the most popular. The artist's
            popularity is calculated from the popularity of all the artist's
            tracks.
        mtype (TypeEnum): The object type.
        uri (str): The [Spotify
            URI](/documentation/web-api/concepts/spotify-uris-ids) for the
            artist.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "external_urls": 'external_urls',
        "followers": 'followers',
        "genres": 'genres',
        "href": 'href',
        "id": 'id',
        "images": 'images',
        "name": 'name',
        "popularity": 'popularity',
        "mtype": 'type',
        "uri": 'uri'
    }

    _optionals = [
        'external_urls',
        'followers',
        'genres',
        'href',
        'id',
        'images',
        'name',
        'popularity',
        'mtype',
        'uri',
    ]

    def __init__(self,
                 external_urls=APIHelper.SKIP,
                 followers=APIHelper.SKIP,
                 genres=APIHelper.SKIP,
                 href=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 images=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 popularity=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 uri=APIHelper.SKIP):
        """Constructor for the ArtistObject class"""

        # Initialize members of the class
        if external_urls is not APIHelper.SKIP:
            self.external_urls = external_urls 
        if followers is not APIHelper.SKIP:
            self.followers = followers 
        if genres is not APIHelper.SKIP:
            self.genres = genres 
        if href is not APIHelper.SKIP:
            self.href = href 
        if id is not APIHelper.SKIP:
            self.id = id 
        if images is not APIHelper.SKIP:
            self.images = images 
        if name is not APIHelper.SKIP:
            self.name = name 
        if popularity is not APIHelper.SKIP:
            self.popularity = popularity 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if uri is not APIHelper.SKIP:
            self.uri = uri 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        external_urls = ExternalUrlObject.from_dictionary(dictionary.get('external_urls')) if 'external_urls' in dictionary.keys() else APIHelper.SKIP
        followers = FollowersObject.from_dictionary(dictionary.get('followers')) if 'followers' in dictionary.keys() else APIHelper.SKIP
        genres = dictionary.get("genres") if dictionary.get("genres") else APIHelper.SKIP
        href = dictionary.get("href") if dictionary.get("href") else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        images = None
        if dictionary.get('images') is not None:
            images = [ImageObject.from_dictionary(x) for x in dictionary.get('images')]
        else:
            images = APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        popularity = dictionary.get("popularity") if dictionary.get("popularity") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        uri = dictionary.get("uri") if dictionary.get("uri") else APIHelper.SKIP
        # Return an object of this model
        return cls(external_urls,
                   followers,
                   genres,
                   href,
                   id,
                   images,
                   name,
                   popularity,
                   mtype,
                   uri)

    @classmethod
    def validate(cls, dictionary):
        """Validates dictionary against class required properties

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            boolean : if dictionary is valid contains required properties.

        """

        if isinstance(dictionary, cls):
            return True

        if not isinstance(dictionary, dict):
            return False

        return True

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'external_urls={(self.external_urls if hasattr(self, "external_urls") else None)!r}, '
                f'followers={(self.followers if hasattr(self, "followers") else None)!r}, '
                f'genres={(self.genres if hasattr(self, "genres") else None)!r}, '
                f'href={(self.href if hasattr(self, "href") else None)!r}, '
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'images={(self.images if hasattr(self, "images") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'popularity={(self.popularity if hasattr(self, "popularity") else None)!r}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!r}, '
                f'uri={(self.uri if hasattr(self, "uri") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'external_urls={(self.external_urls if hasattr(self, "external_urls") else None)!s}, '
                f'followers={(self.followers if hasattr(self, "followers") else None)!s}, '
                f'genres={(self.genres if hasattr(self, "genres") else None)!s}, '
                f'href={(self.href if hasattr(self, "href") else None)!s}, '
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'images={(self.images if hasattr(self, "images") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'popularity={(self.popularity if hasattr(self, "popularity") else None)!s}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!s}, '
                f'uri={(self.uri if hasattr(self, "uri") else None)!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ItemTypeEnum(object):

    """Implementation of the 'Item type' enum.

    Attributes:
        ALBUM: The enum member of type str.
        ARTIST: The enum member of type str.
        PLAYLIST: The enum member of type str.
        TRACK: The enum member of type str.
        SHOW: The enum member of type str.
        EPISODE: The enum member of type str.
        AUDIOBOOK: The enum member of type str.

    """
    ALBUM = 'album'

    ARTIST = 'artist'

    PLAYLIST = 'playlist'

    TRACK = 'track'

    SHOW = 'show'

    EPISODE = 'episode'

    AUDIOBOOK = 'audiobook'




# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper
from spotifywebapiwithfixesandimprovementsfromsonallux.configuration import Server
from spotifywebapiwithfixesandimprovementsfromsonallux.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from spotifywebapiwithfixesandimprovementsfromsonallux.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from spotifywebapiwithfixesandimprovementsfromsonallux.models.audiobook_object import AudiobookObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.many_audiobooks import ManyAudiobooks
from spotifywebapiwithfixesandimprovementsfromsonallux.models.paging_simplified_chapter_object import PagingSimplifiedChapterObject
from spotifywebapiwithfixesandimprovementsfromsonallux.models.paging_saved_audiobook_object import PagingSavedAudiobookObject
from spotifywebapiwithfixesandimprovementsfromsonallux.exceptions.bad_request_exception import BadRequestException
from spotifywebapiwithfixesandimprovementsfromsonallux.exceptions.unauthorized_exception import UnauthorizedException
from spotifywebapiwithfixesandimprovementsfromsonallux.exceptions.forbidden_exception import ForbiddenException
from spotifywebapiwithfixesandimprovementsfromsonallux.exceptions.not_found_exception import NotFoundException
from spotifywebapiwithfixesandimprovementsfromsonallux.exceptions.too_many_requests_exception import TooManyRequestsException


class AudiobooksController(BaseController):

    """A Controller to access Endpoints in the spotifywebapiwithfixesandimprovementsfromsonallux API."""
    def __init__(self, config):
        super(AudiobooksController, self).__init__(config)

    def get_an_audiobook(self,
                         id,
                         market=None):
        """Does a GET request to /audiobooks/{id}.

        Get Spotify catalog information for a single audiobook. Audiobooks are
        only available within the US, UK, Canada, Ireland, New Zealand and
        Australia markets.

        Args:
            id (str): The request template parameter.
            market (str, optional): The request query parameter.

        Returns:
            AudiobookObject: Response from the API. An Audiobook

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/audiobooks/{id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('market')
                         .value(market))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('oauth_2_0'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AudiobookObject.from_dictionary)
            .local_error('400', 'The request contains malformed data in path, query parameters, or body.\n', BadRequestException)
            .local_error('401', 'Bad or expired token. This can happen if the user revoked a token or\nthe access token has expired. You should re-authenticate the user.\n', UnauthorizedException)
            .local_error('403', 'Bad OAuth request (wrong consumer key, bad nonce, expired\ntimestamp...). Unfortunately, re-authenticating the user won\'t help here.\n', ForbiddenException)
            .local_error('404', 'The requested resource cannot be found.\n', NotFoundException)
            .local_error('429', 'The app has exceeded its rate limits.\n', TooManyRequestsException)
        ).execute()

    def get_multiple_audiobooks(self,
                                ids,
                                market=None):
        """Does a GET request to /audiobooks.

        Get Spotify catalog information for several audiobooks identified by
        their Spotify IDs. Audiobooks are only available within the US, UK,
        Canada, Ireland, New Zealand and Australia markets.

        Args:
            ids (str): The request query parameter.
            market (str, optional): The request query parameter.

        Returns:
            ManyAudiobooks: Response from the API. A set of audiobooks. If one
                of the requested audiobooks is unavailable then you'll find a
                `null` item in the `audiobooks` array where the audiobook
                object would otherwise be.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/audiobooks')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('ids')
                         .value(ids))
            .query_param(Parameter()
                         .key('market')
                         .value(market))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('oauth_2_0'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(ManyAudiobooks.from_dictionary)
            .local_error('401', 'Bad or expired token. This can happen if the user revoked a token or\nthe access token has expired. You should re-authenticate the user.\n', UnauthorizedException)
            .local_error('403', 'Bad OAuth request (wrong consumer key, bad nonce, expired\ntimestamp...). Unfortunately, re-authenticating the user won\'t help here.\n', ForbiddenException)
            .local_error('429', 'The app has exceeded its rate limits.\n', TooManyRequestsException)
        ).execute()

    def get_audiobook_chapters(self,
                               id,
                               market=None,
                               limit=20,
                               offset=0):
        """Does a GET request to /audiobooks/{id}/chapters.

        Get Spotify catalog information about an audiobook's chapters.
        Audiobooks are only available within the US, UK, Canada, Ireland, New
        Zealand and Australia markets.

        Args:
            id (str): The request template parameter.
            market (str, optional): The request query parameter.
            limit (int, optional): The request query parameter. Example: 20
            offset (int, optional): The request query parameter. Example: 0

        Returns:
            PagingSimplifiedChapterObject: Response from the API. Pages of
                chapters

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/audiobooks/{id}/chapters')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(id)
                            .should_encode(True))
            .query_param(Parameter()
                         .key('market')
                         .value(market))
            .query_param(Parameter()
                         .key('limit')
                         .value(limit))
            .query_param(Parameter()
                         .key('offset')
                         .value(offset))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('oauth_2_0'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(PagingSimplifiedChapterObject.from_dictionary)
            .local_error('401', 'Bad or expired token. This can happen if the user revoked a token or\nthe access token has expired. You should re-authenticate the user.\n', UnauthorizedException)
            .local_error('403', 'Bad OAuth request (wrong consumer key, bad nonce, expired\ntimestamp...). Unfortunately, re-authenticating the user won\'t help here.\n', ForbiddenException)
            .local_error('429', 'The app has exceeded its rate limits.\n', TooManyRequestsException)
        ).execute()

    def get_users_saved_audiobooks(self,
                                   limit=20,
                                   offset=0):
        """Does a GET request to /me/audiobooks.

        Get a list of the audiobooks saved in the current Spotify user's 'Your
        Music' library.

        Args:
            limit (int, optional): The request query parameter. Example: 20
            offset (int, optional): The request query parameter. Example: 0

        Returns:
            PagingSavedAudiobookObject: Response from the API. Pages of saved
                audiobooks

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/me/audiobooks')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('limit')
                         .value(limit))
            .query_param(Parameter()
                         .key('offset')
                         .value(offset))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('oauth_2_0'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(PagingSavedAudiobookObject.from_dictionary)
            .local_error('401', 'Bad or expired token. This can happen if the user revoked a token or\nthe access token has expired. You should re-authenticate the user.\n', UnauthorizedException)
            .local_error('403', 'Bad OAuth request (wrong consumer key, bad nonce, expired\ntimestamp...). Unfortunately, re-authenticating the user won\'t help here.\n', ForbiddenException)
            .local_error('429', 'The app has exceeded its rate limits.\n', TooManyRequestsException)
        ).execute()

    def save_audiobooks_user(self,
                             ids):
        """Does a PUT request to /me/audiobooks.

        Save one or more audiobooks to the current Spotify user's library.

        Args:
            ids (str): The request query parameter.

        Returns:
            void: Response from the API. Audiobook(s) are saved to the library

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/me/audiobooks')
            .http_method(HttpMethodEnum.PUT)
            .query_param(Parameter()
                         .key('ids')
                         .value(ids))
            .auth(Single('oauth_2_0'))
        ).execute()

    def remove_audiobooks_user(self,
                               ids):
        """Does a DELETE request to /me/audiobooks.

        Remove one or more audiobooks from the Spotify user's library.

        Args:
            ids (str): The request query parameter.

        Returns:
            void: Response from the API. Audiobook(s) have been removed from
                the library

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/me/audiobooks')
            .http_method(HttpMethodEnum.DELETE)
            .query_param(Parameter()
                         .key('ids')
                         .value(ids))
            .auth(Single('oauth_2_0'))
        ).execute()

    def check_users_saved_audiobooks(self,
                                     ids):
        """Does a GET request to /me/audiobooks/contains.

        Check if one or more audiobooks are already saved in the current
        Spotify user's library.

        Args:
            ids (str): The request query parameter.

        Returns:
            List[bool]: Response from the API. Array of booleans

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/me/audiobooks/contains')
            .http_method(HttpMethodEnum.GET)
            .query_param(Parameter()
                         .key('ids')
                         .value(ids))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('oauth_2_0'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .local_error('401', 'Bad or expired token. This can happen if the user revoked a token or\nthe access token has expired. You should re-authenticate the user.\n', UnauthorizedException)
            .local_error('403', 'Bad OAuth request (wrong consumer key, bad nonce, expired\ntimestamp...). Unfortunately, re-authenticating the user won\'t help here.\n', ForbiddenException)
            .local_error('429', 'The app has exceeded its rate limits.\n', TooManyRequestsException)
        ).execute()



__all__ = [
    'api_exception',
    'bad_request_exception',
    'forbidden_exception',
    'not_found_exception',
    'too_many_requests_exception',
    'unauthorized_exception',
    'o_auth_provider_exception',
]



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.models.show_base import ShowBase


class ManySimplifiedShows(object):

    """Implementation of the 'ManySimplifiedShows' model.

    Attributes:
        shows (List[ShowBase]): The model property of type List[ShowBase].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "shows": 'shows'
    }

    def __init__(self,
                 shows=None):
        """Constructor for the ManySimplifiedShows class"""

        # Initialize members of the class
        self.shows = shows 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        shows = None
        if dictionary.get('shows') is not None:
            shows = [ShowBase.from_dictionary(x) for x in dictionary.get('shows')]
        # Return an object of this model
        return cls(shows)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'shows={self.shows!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'shows={self.shows!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper


class CursorObject(object):

    """Implementation of the 'CursorObject' model.

    Attributes:
        after (str): The cursor to use as key to find the next page of items.
        before (str): The cursor to use as key to find the previous page of
            items.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "after": 'after',
        "before": 'before'
    }

    _optionals = [
        'after',
        'before',
    ]

    def __init__(self,
                 after=APIHelper.SKIP,
                 before=APIHelper.SKIP):
        """Constructor for the CursorObject class"""

        # Initialize members of the class
        if after is not APIHelper.SKIP:
            self.after = after 
        if before is not APIHelper.SKIP:
            self.before = before 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        after = dictionary.get("after") if dictionary.get("after") else APIHelper.SKIP
        before = dictionary.get("before") if dictionary.get("before") else APIHelper.SKIP
        # Return an object of this model
        return cls(after,
                   before)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'after={(self.after if hasattr(self, "after") else None)!r}, '
                f'before={(self.before if hasattr(self, "before") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'after={(self.after if hasattr(self, "after") else None)!s}, '
                f'before={(self.before if hasattr(self, "before") else None)!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper


class DisallowsObject(object):

    """Implementation of the 'DisallowsObject' model.

    Attributes:
        interrupting_playback (bool): Interrupting playback. Optional field.
        pausing (bool): Pausing. Optional field.
        resuming (bool): Resuming. Optional field.
        seeking (bool): Seeking playback location. Optional field.
        skipping_next (bool): Skipping to the next context. Optional field.
        skipping_prev (bool): Skipping to the previous context. Optional field.
        toggling_repeat_context (bool): Toggling repeat context flag. Optional
            field.
        toggling_shuffle (bool): Toggling shuffle flag. Optional field.
        toggling_repeat_track (bool): Toggling repeat track flag. Optional
            field.
        transferring_playback (bool): Transfering playback between devices.
            Optional field.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "interrupting_playback": 'interrupting_playback',
        "pausing": 'pausing',
        "resuming": 'resuming',
        "seeking": 'seeking',
        "skipping_next": 'skipping_next',
        "skipping_prev": 'skipping_prev',
        "toggling_repeat_context": 'toggling_repeat_context',
        "toggling_shuffle": 'toggling_shuffle',
        "toggling_repeat_track": 'toggling_repeat_track',
        "transferring_playback": 'transferring_playback'
    }

    _optionals = [
        'interrupting_playback',
        'pausing',
        'resuming',
        'seeking',
        'skipping_next',
        'skipping_prev',
        'toggling_repeat_context',
        'toggling_shuffle',
        'toggling_repeat_track',
        'transferring_playback',
    ]

    def __init__(self,
                 interrupting_playback=APIHelper.SKIP,
                 pausing=APIHelper.SKIP,
                 resuming=APIHelper.SKIP,
                 seeking=APIHelper.SKIP,
                 skipping_next=APIHelper.SKIP,
                 skipping_prev=APIHelper.SKIP,
                 toggling_repeat_context=APIHelper.SKIP,
                 toggling_shuffle=APIHelper.SKIP,
                 toggling_repeat_track=APIHelper.SKIP,
                 transferring_playback=APIHelper.SKIP):
        """Constructor for the DisallowsObject class"""

        # Initialize members of the class
        if interrupting_playback is not APIHelper.SKIP:
            self.interrupting_playback = interrupting_playback 
        if pausing is not APIHelper.SKIP:
            self.pausing = pausing 
        if resuming is not APIHelper.SKIP:
            self.resuming = resuming 
        if seeking is not APIHelper.SKIP:
            self.seeking = seeking 
        if skipping_next is not APIHelper.SKIP:
            self.skipping_next = skipping_next 
        if skipping_prev is not APIHelper.SKIP:
            self.skipping_prev = skipping_prev 
        if toggling_repeat_context is not APIHelper.SKIP:
            self.toggling_repeat_context = toggling_repeat_context 
        if toggling_shuffle is not APIHelper.SKIP:
            self.toggling_shuffle = toggling_shuffle 
        if toggling_repeat_track is not APIHelper.SKIP:
            self.toggling_repeat_track = toggling_repeat_track 
        if transferring_playback is not APIHelper.SKIP:
            self.transferring_playback = transferring_playback 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        interrupting_playback = dictionary.get("interrupting_playback") if "interrupting_playback" in dictionary.keys() else APIHelper.SKIP
        pausing = dictionary.get("pausing") if "pausing" in dictionary.keys() else APIHelper.SKIP
        resuming = dictionary.get("resuming") if "resuming" in dictionary.keys() else APIHelper.SKIP
        seeking = dictionary.get("seeking") if "seeking" in dictionary.keys() else APIHelper.SKIP
        skipping_next = dictionary.get("skipping_next") if "skipping_next" in dictionary.keys() else APIHelper.SKIP
        skipping_prev = dictionary.get("skipping_prev") if "skipping_prev" in dictionary.keys() else APIHelper.SKIP
        toggling_repeat_context = dictionary.get("toggling_repeat_context") if "toggling_repeat_context" in dictionary.keys() else APIHelper.SKIP
        toggling_shuffle = dictionary.get("toggling_shuffle") if "toggling_shuffle" in dictionary.keys() else APIHelper.SKIP
        toggling_repeat_track = dictionary.get("toggling_repeat_track") if "toggling_repeat_track" in dictionary.keys() else APIHelper.SKIP
        transferring_playback = dictionary.get("transferring_playback") if "transferring_playback" in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(interrupting_playback,
                   pausing,
                   resuming,
                   seeking,
                   skipping_next,
                   skipping_prev,
                   toggling_repeat_context,
                   toggling_shuffle,
                   toggling_repeat_track,
                   transferring_playback)

    @classmethod
    def validate(cls, dictionary):
        """Validates dictionary against class required properties

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            boolean : if dictionary is valid contains required properties.

        """

        if isinstance(dictionary, cls):
            return True

        if not isinstance(dictionary, dict):
            return False

        return True

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'interrupting_playback={(self.interrupting_playback if hasattr(self, "interrupting_playback") else None)!r}, '
                f'pausing={(self.pausing if hasattr(self, "pausing") else None)!r}, '
                f'resuming={(self.resuming if hasattr(self, "resuming") else None)!r}, '
                f'seeking={(self.seeking if hasattr(self, "seeking") else None)!r}, '
                f'skipping_next={(self.skipping_next if hasattr(self, "skipping_next") else None)!r}, '
                f'skipping_prev={(self.skipping_prev if hasattr(self, "skipping_prev") else None)!r}, '
                f'toggling_repeat_context={(self.toggling_repeat_context if hasattr(self, "toggling_repeat_context") else None)!r}, '
                f'toggling_shuffle={(self.toggling_shuffle if hasattr(self, "toggling_shuffle") else None)!r}, '
                f'toggling_repeat_track={(self.toggling_repeat_track if hasattr(self, "toggling_repeat_track") else None)!r}, '
                f'transferring_playback={(self.transferring_playback if hasattr(self, "transferring_playback") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'interrupting_playback={(self.interrupting_playback if hasattr(self, "interrupting_playback") else None)!s}, '
                f'pausing={(self.pausing if hasattr(self, "pausing") else None)!s}, '
                f'resuming={(self.resuming if hasattr(self, "resuming") else None)!s}, '
                f'seeking={(self.seeking if hasattr(self, "seeking") else None)!s}, '
                f'skipping_next={(self.skipping_next if hasattr(self, "skipping_next") else None)!s}, '
                f'skipping_prev={(self.skipping_prev if hasattr(self, "skipping_prev") else None)!s}, '
                f'toggling_repeat_context={(self.toggling_repeat_context if hasattr(self, "toggling_repeat_context") else None)!s}, '
                f'toggling_shuffle={(self.toggling_shuffle if hasattr(self, "toggling_shuffle") else None)!s}, '
                f'toggling_repeat_track={(self.toggling_repeat_track if hasattr(self, "toggling_repeat_track") else None)!s}, '
                f'transferring_playback={(self.transferring_playback if hasattr(self, "transferring_playback") else None)!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ReleaseDatePrecisionEnum(object):

    """Implementation of the 'ReleaseDatePrecision' enum.

    The precision with which `release_date` value is known.

    Attributes:
        YEAR: The enum member of type str.
        MONTH: The enum member of type str.
        DAY: The enum member of type str.

    """
    _all_values = ['year', 'month', 'day']
    YEAR = 'year'

    MONTH = 'month'

    DAY = 'day'

    @classmethod
    def validate(cls, value):
        """Validates value contains in enum

        Args:
            value: the value to be validated

        Returns:
            boolean : if value is valid enum values.

        """
        return value in cls._all_values
   


# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper


class MePlayerPlayRequest(object):

    """Implementation of the 'Me Player Play Request' model.

    Attributes:
        context_uri (str): Optional. Spotify URI of the context to play. Valid
            contexts are albums, artists & playlists.
            `{context_uri:"spotify:album:1Je1IMUlBXcx1Fz0WE7oPT"}`
        uris (List[str]): Optional. A JSON array of the Spotify track URIs to
            play. For example: `{"uris":
            ["spotify:track:4iV5W9uYEdYUVa79Axb7Rh",
            "spotify:track:1301WleyT98MSxVHPZCA6M"]}`
        offset (Any): Optional. Indicates from where in the context playback
            should start. Only available when context_uri corresponds to an
            album or playlist object "position" is zero based and can’t be
            negative. Example: `"offset": {"position": 5}` "uri" is a string
            representing the uri of the item to start at. Example: `"offset":
            {"uri": "spotify:track:1301WleyT98MSxVHPZCA6M"}`
        position_ms (int): Indicates from what position to start playback.
            Must be a positive number. Passing in a position that is greater
            than the length of the track will cause the player to start
            playing the next song.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "context_uri": 'context_uri',
        "uris": 'uris',
        "offset": 'offset',
        "position_ms": 'position_ms'
    }

    _optionals = [
        'context_uri',
        'uris',
        'offset',
        'position_ms',
    ]

    def __init__(self,
                 context_uri=APIHelper.SKIP,
                 uris=APIHelper.SKIP,
                 offset=APIHelper.SKIP,
                 position_ms=APIHelper.SKIP):
        """Constructor for the MePlayerPlayRequest class"""

        # Initialize members of the class
        if context_uri is not APIHelper.SKIP:
            self.context_uri = context_uri 
        if uris is not APIHelper.SKIP:
            self.uris = uris 
        if offset is not APIHelper.SKIP:
            self.offset = offset 
        if position_ms is not APIHelper.SKIP:
            self.position_ms = position_ms 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        context_uri = dictionary.get("context_uri") if dictionary.get("context_uri") else APIHelper.SKIP
        uris = dictionary.get("uris") if dictionary.get("uris") else APIHelper.SKIP
        offset = dictionary.get("offset") if dictionary.get("offset") else APIHelper.SKIP
        position_ms = dictionary.get("position_ms") if dictionary.get("position_ms") else APIHelper.SKIP
        # Return an object of this model
        return cls(context_uri,
                   uris,
                   offset,
                   position_ms)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'context_uri={(self.context_uri if hasattr(self, "context_uri") else None)!r}, '
                f'uris={(self.uris if hasattr(self, "uris") else None)!r}, '
                f'offset={(self.offset if hasattr(self, "offset") else None)!r}, '
                f'position_ms={(self.position_ms if hasattr(self, "position_ms") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'context_uri={(self.context_uri if hasattr(self, "context_uri") else None)!s}, '
                f'uris={(self.uris if hasattr(self, "uris") else None)!s}, '
                f'offset={(self.offset if hasattr(self, "offset") else None)!s}, '
                f'position_ms={(self.position_ms if hasattr(self, "position_ms") else None)!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper
from spotifywebapiwithfixesandimprovementsfromsonallux.exceptions.api_exception import APIException
from spotifywebapiwithfixesandimprovementsfromsonallux.models.error_object import ErrorObject


class BadRequestException(APIException):
    def __init__(self, reason, response):
        """Constructor for the BadRequestException class

        Args:
            reason (string): The reason (or error message) for the Exception
                to be raised.
            response (HttpResponse): The HttpResponse of the API call.

        """
        super(BadRequestException, self).__init__(reason, response)
        dictionary = APIHelper.json_deserialize(self.response.text)
        if isinstance(dictionary, dict):
            self.unbox(dictionary)

    def unbox(self, dictionary):
        """Populates the properties of this object by extracting them from a dictionary.

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        """
        self.error = ErrorObject.from_dictionary(dictionary.get('error')) if dictionary.get('error') else None

    def __str__(self):
        base_str = super().__str__()
        return (f'{self.__class__.__name__}('
                f'{base_str[base_str.find("(") + 1:-1]}, '
                f'error={self.error!s})')



# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class IncludeExternalEnum(object):

    """Implementation of the 'Include External' enum.

    If `include_external=audio` is specified it signals that the client can
    play externally hosted audio content, and marks
    the content as playable in the response. By default externally hosted
    audio content is marked as unplayable in the response.

    Attributes:
        AUDIO: The enum member of type str.

    """
    AUDIO = 'audio'




# -*- coding: utf-8 -*-

"""
spotifywebapiwithfixesandimprovementsfromsonallux

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from spotifywebapiwithfixesandimprovementsfromsonallux.api_helper import APIHelper


class Meta(object):

    """Implementation of the 'Meta' model.

    Attributes:
        analyzer_version (str): The version of the Analyzer used to analyze
            this track.
        platform (str): The platform used to read the track's audio data.
        detailed_status (str): A detailed status code for this track. If
            analysis data is missing, this code may explain why.
        status_code (int): The return code of the analyzer process. 0 if
            successful, 1 if any errors occurred.
        timestamp (int): The Unix timestamp (in seconds) at which this track
            was analyzed.
        analysis_time (float): The amount of time taken to analyze this track.
        input_process (str): The method used to read the track's audio data.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "analyzer_version": 'analyzer_version',
        "platform": 'platform',
        "detailed_status": 'detailed_status',
        "status_code": 'status_code',
        "timestamp": 'timestamp',
        "analysis_time": 'analysis_time',
        "input_process": 'input_process'
    }

    _optionals = [
        'analyzer_version',
        'platform',
        'detailed_status',
        'status_code',
        'timestamp',
        'analysis_time',
        'input_process',
    ]

    def __init__(self,
                 analyzer_version=APIHelper.SKIP,
                 platform=APIHelper.SKIP,
                 detailed_status=APIHelper.SKIP,
                 status_code=APIHelper.SKIP,
                 timestamp=APIHelper.SKIP,
                 analysis_time=APIHelper.SKIP,
                 input_process=APIHelper.SKIP):
        """Constructor for the Meta class"""

        # Initialize members of the class
        if analyzer_version is not APIHelper.SKIP:
            self.analyzer_version = analyzer_version 
        if platform is not APIHelper.SKIP:
            self.platform = platform 
        if detailed_status is not APIHelper.SKIP:
            self.detailed_status = detailed_status 
        if status_code is not APIHelper.SKIP:
            self.status_code = status_code 
        if timestamp is not APIHelper.SKIP:
            self.timestamp = timestamp 
        if analysis_time is not APIHelper.SKIP:
            self.analysis_time = analysis_time 
        if input_process is not APIHelper.SKIP:
            self.input_process = input_process 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        analyzer_version = dictionary.get("analyzer_version") if dictionary.get("analyzer_version") else APIHelper.SKIP
        platform = dictionary.get("platform") if dictionary.get("platform") else APIHelper.SKIP
        detailed_status = dictionary.get("detailed_status") if dictionary.get("detailed_status") else APIHelper.SKIP
        status_code = dictionary.get("status_code") if dictionary.get("status_code") else APIHelper.SKIP
        timestamp = dictionary.get("timestamp") if dictionary.get("timestamp") else APIHelper.SKIP
        analysis_time = dictionary.get("analysis_time") if dictionary.get("analysis_time") else APIHelper.SKIP
        input_process = dictionary.get("input_process") if dictionary.get("input_process") else APIHelper.SKIP
        # Return an object of this model
        return cls(analyzer_version,
                   platform,
                   detailed_status,
                   status_code,
                   timestamp,
                   analysis_time,
                   input_process)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'analyzer_version={(self.analyzer_version if hasattr(self, "analyzer_version") else None)!r}, '
                f'platform={(self.platform if hasattr(self, "platform") else None)!r}, '
                f'detailed_status={(self.detailed_status if hasattr(self, "detailed_status") else None)!r}, '
                f'status_code={(self.status_code if hasattr(self, "status_code") else None)!r}, '
                f'timestamp={(self.timestamp if hasattr(self, "timestamp") else None)!r}, '
                f'analysis_time={(self.analysis_time if hasattr(self, "analysis_time") else None)!r}, '
                f'input_process={(self.input_process if hasattr(self, "input_process") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'analyzer_version={(self.analyzer_version if hasattr(self, "analyzer_version") else None)!s}, '
                f'platform={(self.platform if hasattr(self, "platform") else None)!s}, '
                f'detailed_status={(self.detailed_status if hasattr(self, "detailed_status") else None)!s}, '
                f'status_code={(self.status_code if hasattr(self, "status_code") else None)!s}, '
                f'timestamp={(self.timestamp if hasattr(self, "timestamp") else None)!s}, '
                f'analysis_time={(self.analysis_time if hasattr(self, "analysis_time") else None)!s}, '
                f'input_process={(self.input_process if hasattr(self, "input_process") else None)!s})')
